Enum block_buffer::Iso7816 [−][src]
pub enum Iso7816 {}Trait Implementations
impl Clone for Iso7816[src]
impl Clone for Iso7816fn clone(&self) -> Iso7816[src]
fn clone(&self) -> Iso7816Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Copy for Iso7816[src]
impl Copy for Iso7816impl Debug for Iso7816[src]
impl Debug for Iso7816fn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Eq for Iso7816[src]
impl Eq for Iso7816impl Hash for Iso7816[src]
impl Hash for Iso7816fn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Iso7816[src]
impl Ord for Iso7816fn cmp(&self, other: &Iso7816) -> Ordering[src]
fn cmp(&self, other: &Iso7816) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl PartialEq for Iso7816[src]
impl PartialEq for Iso7816fn eq(&self, other: &Iso7816) -> bool[src]
fn eq(&self, other: &Iso7816) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl PartialOrd for Iso7816[src]
impl PartialOrd for Iso7816fn partial_cmp(&self, other: &Iso7816) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &Iso7816) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Padding for Iso7816[src]
impl Padding for Iso7816impl Unpadding for Iso7816[src]
impl Unpadding for Iso7816fn unpad(data: &[u8]) -> Result<&[u8], UnpadError>[src]
fn unpad(data: &[u8]) -> Result<&[u8], UnpadError>Unpad given data by truncating it according to the used padding. In case of the malformed padding will return UnpadError Read more