Enum block_buffer::Pkcs7 [−][src]
pub enum Pkcs7 {}Trait Implementations
impl Clone for Pkcs7[src]
impl Clone for Pkcs7fn clone(&self) -> Pkcs7[src]
fn clone(&self) -> Pkcs7Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Copy for Pkcs7[src]
impl Copy for Pkcs7impl Debug for Pkcs7[src]
impl Debug for Pkcs7fn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Eq for Pkcs7[src]
impl Eq for Pkcs7impl Hash for Pkcs7[src]
impl Hash for Pkcs7fn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Pkcs7[src]
impl Ord for Pkcs7fn cmp(&self, other: &Pkcs7) -> Ordering[src]
fn cmp(&self, other: &Pkcs7) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl PartialEq for Pkcs7[src]
impl PartialEq for Pkcs7fn eq(&self, other: &Pkcs7) -> bool[src]
fn eq(&self, other: &Pkcs7) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl PartialOrd for Pkcs7[src]
impl PartialOrd for Pkcs7fn partial_cmp(&self, other: &Pkcs7) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &Pkcs7) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Padding for Pkcs7[src]
impl Padding for Pkcs7impl Unpadding for Pkcs7[src]
impl Unpadding for Pkcs7fn unpad(data: &[u8]) -> Result<&[u8], UnpadError>[src]
fn unpad(data: &[u8]) -> Result<&[u8], UnpadError>Unpad given data by truncating it according to the used padding. In case of the malformed padding will return UnpadError Read more